from django.urls import reverse
from django.utils.module_loading import import_string

default_app_config = "django_comments_ink.apps.CommentsInkConfig"


def get_model():
    from django_comments_ink.conf import settings

    return import_string(settings.COMMENTS_INK_MODEL)


def get_form():
    from django_comments_ink.conf import settings

    return import_string(settings.COMMENTS_INK_FORM_CLASS)


def get_comment_reactions_enum():
    from django_comments_ink.conf import settings

    return import_string(settings.COMMENTS_INK_COMMENT_REACTIONS_ENUM)


def get_object_reactions_enum():
    from django_comments_ink.conf import settings

    return import_string(settings.COMMENTS_INK_OBJECT_REACTIONS_ENUM)


def get_form_target():
    return reverse("comments-ink-post")


VERSION = (0, 1, 0, "f", 0)  # following PEP 440


def get_version():
    version = "%s.%s.%s" % (VERSION[0], VERSION[1], VERSION[2])
    if VERSION[3] != "f":
        version = "%s%s%s" % (version, VERSION[3], VERSION[4])
    return version



from django.contrib.auth import views as auth_views
from django.contrib.staticfiles.urls import staticfiles_urlpatterns
from django.urls import include, re_path
from django_comments_ink.tests import views

urlpatterns = [
    re_path(r"^accounts/login/$", auth_views.LoginView.as_view()),
    re_path(
        r"^articles/(?P<year>\d{4})/(?P<month>\d{1,2})/(?P<day>\d{1,2})/"
        r"(?P<slug>[-\w]+)/$",
        views.dummy_view,
        name="article-detail",
    ),
    re_path(
        r"^diary/(?P<year>\d{4})/(?P<month>\d{1,2})/(?P<day>\d{1,2})/",
        views.dummy_view,
        name="diary-detail",
    ),
    re_path(r"^comments/", include("django_comments_ink.urls")),
    re_path(
        r"^api-auth/",
        include("rest_framework.urls", namespace="rest_framework"),
    ),
]
urlpatterns += staticfiles_urlpatterns()



from datetime import datetime
from io import StringIO

import pytest
from django.contrib.contenttypes.models import ContentType
from django.contrib.sites.models import Site
from django.core.management import call_command
from django.db.utils import ConnectionHandler
from django_comments.models import Comment
from django_comments_ink.management.commands import populate_comments
from django_comments_ink.models import InkComment


def create_comments(an_article, model=Comment):
    article_ct = ContentType.objects.get(app_label="tests", model="article")
    site = Site.objects.get(pk=1)
    for i in range(5):
        model.objects.create(
            content_type=article_ct,
            object_pk=an_article.id,
            content_object=an_article,
            comment="Yet another comment",
            submit_date=datetime.now(),
            site=site,
        )


@pytest.mark.django_db
def test_populate_comments(an_article):
    create_comments(an_article)
    output = StringIO()
    call_command("populate_comments", stdout=output)
    assert output.getvalue() == "Added 5 InkComment object(s).\n"


@pytest.mark.django_db
def test_populate_comments_raise_ConnectionDoesNotExist(an_article):
    create_comments(an_article)
    output = StringIO()
    call_command("populate_comments", "nondb", stdout=output)
    assert output.getvalue() == (
        "DB connection 'nondb' does not exist.\n"
        "Added 0 InkComment object(s).\n"
    )


@pytest.mark.django_db
def test_populate_comments_raise_IntegrityError_1(an_article):
    create_comments(an_article, model=InkComment)
    output = StringIO()
    call_command("populate_comments", stdout=output)
    assert output.getvalue() == (
        "Table 'django_comments_ink_inkcomment' must be empty.\n"
        "Added 0 InkComment object(s).\n"
    )
